#if 0
/*
  Copyright (C) 2009 X. Andrade

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2, or (at your option)
  any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.

  $Id: io_binary.h 13828 2015-04-11 21:54:46Z dstrubbe $

Note: This comment header is excluded by the preprocessor since this
file is included in both C and Fortran source files, and thus neither
comment style should be used.
*/
#endif

#ifndef IO_BINARY_H
#define IO_BINARY_H

#if 0
/* These values must not be changed, as they are used in the restart files */
#endif

#define TYPE_FLOAT          0
#define TYPE_DOUBLE         1
#define TYPE_FLOAT_COMPLEX  2
#define TYPE_DOUBLE_COMPLEX 3
#define TYPE_INT_32         4
#define TYPE_INT_64         5

#endif
